tensor_study_solver_symbol

Function tensor_study_solver_symbol 

pub fn tensor_study_solver_symbol() -> Symbol
Stable registry symbol for the solver selected by an active Tensor executor.

Provider libraries export this value without replacing the deterministic registry default at study_solver_symbol.